# -*- coding: utf-8 -*-
# Generated by Django 1.9.1 on 2016-01-11 02:08
from __future__ import unicode_literals

from django.db import migrations, models

try:
    import jsonfield.fields
    field = jsonfield.fields.JSONField()
except ImportError:
    field = models.TextField()


class Migration(migrations.Migration):

    dependencies = [
        ('eventlog', '0002_auto_20150113_1450'),
    ]

    operations = [
        migrations.AlterField(
            model_name='log',
            name='extra',
            field=field,
        ),
    ]
